summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilotAppInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilotAppInfo.h')
-rw-r--r--kpilot/lib/pilotAppInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kpilot/lib/pilotAppInfo.h b/kpilot/lib/pilotAppInfo.h
index d5db9e358..b14cf0ace 100644
--- a/kpilot/lib/pilotAppInfo.h
+++ b/kpilot/lib/pilotAppInfo.h
@@ -96,15 +96,15 @@ public:
return fLen;
} ;
- /** @see findCategory(const QString &name, bool unknownIsUnfiled, struct CategoryAppInfo *info). */
- inline int findCategory(const QString &name, bool unknownIsUnfiled = false) const
+ /** @see findCategory(const TQString &name, bool unknownIsUnfiled, struct CategoryAppInfo *info). */
+ inline int findCategory(const TQString &name, bool unknownIsUnfiled = false) const
{
return Pilot::findCategory(fC,name,unknownIsUnfiled);
} ;
/** Gets a single category name. Returns QString::null if there is no
* such category number @p i . */
- inline QString categoryName(unsigned int i) const
+ inline TQString categoryName(unsigned int i) const
{
return Pilot::categoryName(fC,i);
}
@@ -113,7 +113,7 @@ public:
* on failure, e.g. the index @p i was out of range or the category name
* was invalid. Category names that are too long are truncated to 15 characters.
*/
- bool setCategoryName(unsigned int i, const QString &s);
+ bool setCategoryName(unsigned int i, const TQString &s);
/** For debugging, display all the category names */
inline void dump() const
@@ -96,15 +96,15 @@ public:
return Pilot::findCategory(fC,name,unknownIsUnfiled);
} ;
- /** Gets a single category name. Returns QString::null if there is no
+ /** Gets a single category name. Returns TQString::null if there is no
* such category number @p i . */